@@ -68,12 +68,18 @@ QStandardItem *StandardItemFactory::createItemForUrl(const QString& urlString, D
         // or they may be other types such as links.
         //
         // first look in the KDE service database to see if this file is a service,
+        // then we try to look it up by storage id (for eg. system settings entries)
         // otherwise represent it as a generic .desktop file
         KService::Ptr service = KService::serviceByDesktopPath(url.toLocalFile());
         if (service) {
             return createItemForService(service, displayOrder);
         }
 
+        service = KService::serviceByStorageId(urlString);
+        if (service) {
+            return createItemForService(service, displayOrder);
+        }
+
         item = new QStandardItem;
         KDesktopFile desktopFile(url.toLocalFile());
         item->setText(QFileInfo(urlString.mid(0, urlString.lastIndexOf('.'))).completeBaseName());
@@ -182,7 +188,8 @@ QStringList Kickoff::systemApplicationList()
     KConfigGroup appsGroup = componentData().config()->group("SystemApplications");
     QStringList apps;
     apps << "systemsettings";
-    apps = appsGroup.readEntry("DesktopFiles", apps);
+    apps << appsGroup.readEntry("DesktopFiles", apps);
+    apps.removeDuplicates();
     return apps;
 }
 
