@@ -292,6 +292,12 @@ void Backend::itemContextMenu(QQuickItem *item, QObject *configAction)
         m_contextMenu->setMinimumWidth(item->width());
     }
 
+    // Ungrab before showing the menu so the Qt Quick View doesn't stumble
+    // over the pointer leaving its window while handling a click.
+    if (item->window()->mouseGrabberItem()) {
+        item->window()->mouseGrabberItem()->ungrabMouse();
+    }
+
     // Close menu when the delegate is destroyed.
     connect(item, &QQuickItem::destroyed, m_contextMenu.data(), &TaskManager::BasicMenu::deleteLater);
 
