@@ -246,13 +246,10 @@ void KCMKeyboardWidget::addLayout()
     updateLoopCount();
 }
 
-static
-inline int min(int x, int y) { return x < y ? x : y; }
-
 void KCMKeyboardWidget::updateLoopCount()
 {
-	int maxLoop = min(X11Helper::MAX_GROUP_COUNT, keyboardConfig->layouts.count() - 1);
-	uiWidget->layoutLoopCountSpinBox->setMaximum(maxLoop);
+	int maxLoop = qMin(X11Helper::MAX_GROUP_COUNT, keyboardConfig->layouts.count() - 1);
+	uiWidget->layoutLoopCountSpinBox->setMaximum(qMax(MIN_LOOPING_COUNT, maxLoop));
 
 	bool layoutsConfigured = uiWidget->layoutsGroupBox->isChecked();
 
@@ -274,12 +271,12 @@ void KCMKeyboardWidget::updateLoopCount()
 	if( uiWidget->layoutLoopingCheckBox->isChecked() ) {
 		if( uiWidget->layoutLoopCountSpinBox->text().isEmpty() ) {
 			uiWidget->layoutLoopCountSpinBox->setValue(maxLoop);
-//			keyboardConfig->layoutLoopCount = maxLoop;
+			keyboardConfig->layoutLoopCount = maxLoop;
 		}
 	}
 	else {
 		uiWidget->layoutLoopCountSpinBox->clear();
-//		keyboardConfig->layoutLoopCount = KeyboardConfig::NO_LOOPING;
+		keyboardConfig->layoutLoopCount = KeyboardConfig::NO_LOOPING;
 	}
 }
 
@@ -307,7 +304,7 @@ void KCMKeyboardWidget::initializeLayoutsUI()
 	uiWidget->layoutsTableView->setColumnWidth(LayoutsTableModel::DISPLAY_NAME_COLUMN, 50);
 	uiWidget->layoutsTableView->setColumnWidth(LayoutsTableModel::SHORTCUT_COLUMN, 130);
 
-	connect(layoutsTableModel, SIGNAL(dataChanged(QModelIndex,QModelIndex)), this, SLOT(uiChanged()));
+	connect(layoutsTableModel, &LayoutsTableModel::dataChanged, this, [this]() { Q_EMIT changed(true); });
 
 	uiWidget->layoutLoopCountSpinBox->setMinimum(MIN_LOOPING_COUNT);
 
@@ -380,13 +377,17 @@ void KCMKeyboardWidget::previewLayout(){
 
     KeyboardPainter* layoutPreview = new KeyboardPainter();
     const LayoutInfo* layoutInfo = rules->getLayoutInfo(country);
+    if (!layoutInfo) {
+        return;
+    }
+
     foreach(const VariantInfo* variantInfo, layoutInfo->variantInfos) {
         if(variant==variantInfo->description){
             variant=variantInfo->name;
             break;
         }
     }
-    
+
     QString title = Flags::getLongText( LayoutUnit(country, variant), rules );
     layoutPreview->generateKeyboardLayout(country,variant, model, title);
     layoutPreview->setModal(true);
@@ -581,7 +582,7 @@ void KCMKeyboardWidget::configureXkbOptionsChanged()
 	if( uiWidget->configureKeyboardOptionsChk->isChecked() && keyboardConfig->xkbOptions.isEmpty() ) {
 		populateWithCurrentXkbOptions();
 	}
-	((LayoutsTableModel*)uiWidget->xkbOptionsTreeView->model())->refresh();
+	((XkbOptionsTreeModel*)uiWidget->xkbOptionsTreeView->model())->reset();
 	uiChanged();
 }
 
@@ -644,11 +645,10 @@ void KCMKeyboardWidget::updateShortcutsUI()
 
 	delete actionCollection;
 	actionCollection = new KeyboardLayoutActionCollection(this, true);
-	//QAction* toggleAction = 
-	actionCollection->getToggeAction();
-//    const auto shortcuts = KGlobalAccel::self()->shortcut(toggleAction);
-//    uiWidget->kdeKeySequence->setKeySequence(shortcuts.isEmpty() ? QKeySequence() : shortcuts.first());
-//    actionCollection->loadLayoutShortcuts(keyboardConfig->layouts, rules);
+	QAction* toggleAction = actionCollection->getToggeAction();
+	const auto shortcuts = KGlobalAccel::self()->shortcut(toggleAction);
+	uiWidget->kdeKeySequence->setKeySequence(shortcuts.isEmpty() ? QKeySequence() : shortcuts.first());
+	actionCollection->loadLayoutShortcuts(keyboardConfig->layouts, rules);
 	layoutsTableModel->refresh();
 }
 
@@ -670,11 +670,16 @@ void KCMKeyboardWidget::updateLayoutsUI() {
 	uiWidget->layoutLoopingCheckBox->setChecked(loopingOn);
 	uiWidget->layoutLoopingGroupBox->setEnabled(loopingOn);
 	if( loopingOn ) {
+		// Set maximum to 99 to make sure following setValue succeeds
+		// Correct maximum value will be set in updateLoopCount()
+		uiWidget->layoutLoopCountSpinBox->setMaximum(99);
 		uiWidget->layoutLoopCountSpinBox->setValue(keyboardConfig->layoutLoopCount);
 	}
 	else {
 		uiWidget->layoutLoopCountSpinBox->clear();
 	}
+
+	updateLoopCount();
 }
 
 void KCMKeyboardWidget::updateHardwareUI()
