@@ -22,14 +22,17 @@
 
 #include "ui_kcm_keyboard.h"
 
-#include <kcomponentdata.h>
 #include <QTabWidget>
+#include <QLoggingCategory>
+
+
+Q_DECLARE_LOGGING_CATEGORY(KCM_KEYBOARD)
+
 
 class QWidget;
 class KeyboardConfig;
 class Rules;
 class Flags;
-class KComponentData;
 class QString;
 class QPushButton;
 class LayoutsTableModel;
@@ -68,7 +71,9 @@ private Q_SLOTS:
     void moveDown();
     void configureLayoutsChanged();
     void configureXkbOptionsChanged();
+#ifdef NEW_GEOMETRY
     void previewLayout();
+#endif
 
 private:
     Rules *rules;
